@@ -1,3 +1,4 @@
+import re
 from traefikswarm import Context
 
 def configure_argparser(parser):
@@ -13,6 +14,7 @@ def configure_argparser(parser):
     parser.add_argument('--https', help='Use HTTPS for communication with backend', action='store_true', default=None)
     parser.add_argument('--http', help='Use HTTP for communication with backend (default)', action='store_false', dest='https')
     parser.add_argument('--tcp', help='Expose TCP directly', action='store_true', dest='tcp')
+    parser.add_argument('--tls', help='Terminate TLS on TCP endpoint', action='store_true', dest='tls')
 
 def execute(ctx: Context):
     args = ctx.args
@@ -37,11 +39,12 @@ def execute(ctx: Context):
 
     hosts = []
     rule = svc.labels.get(f'{lprefix}.rule', '')
-    if rule.endswith('`)'):
-        if rule.startswith('HostRegexp(`'):
-            hosts = rule[12:-2].replace('{domain:.+}', '*').split('`,`')
-        elif rule.startswith('Host(`'):
-            hosts = rule[6:-2].split('`,`')
+    match = re.fullmatch('(Host(?:SNI)?(?:Regexp)?)\(`(.+)`\)', rule)
+    if match:
+        if match[1].endswith('Regexp'):
+            hosts = match[2].replace('{domain:.+}', '*').split('`,`')
+        elif not (match[1] == 'HostSNI' and match[2] == '*'):
+            hosts = match[2].split('`,`')
     
     for h in args.host_rm or ():
         hosts.remove(h)
@@ -54,9 +57,9 @@ def execute(ctx: Context):
     sni = 'SNI' if args.tcp else ''
     if hosts:
         if wild:
-            rule = 'Host{sni}Regexp(`' + '`,`'.join((h.replace('*', '{domain:.+}') for h in hosts)) + '`)'
+            rule = f'Host{sni}Regexp(`' + '`,`'.join((h.replace('*', '{domain:.+}') for h in hosts)) + '`)'
         else:
-            rule = 'Host{sni}(`' + '`,`'.join(hosts) + '`)'
+            rule = f'Host{sni}(`' + '`,`'.join(hosts) + '`)'
     else:
         rule = 'HostSNI(`*`)' if args.tcp else 'PathPrefix(`/`)'     # catch-all
 
@@ -64,6 +67,8 @@ def execute(ctx: Context):
         entrypoints = ['https']
 
     svc.ensure_label('traefik.enable', 'true')
+    svc.ensure_label('traefik.docker.network', 'traefik')
+    svc.ensure_network(ctx.traefik_network)
     if args.lbswarm == True:
         svc.ensure_label('traefik.docker.lbswarm', 'true')
     elif args.lbtraefik == True:
@@ -79,3 +84,8 @@ def execute(ctx: Context):
             svc.ensure_label(f'traefik.http.services.{router}.loadbalancer.server.scheme', 'https')
         elif args.https == False:
             svc.remove_label(f'traefik.http.services.{router}.loadbalancer.server.scheme')
+    if args.tcp:
+        if args.tls:
+            svc.ensure_label(f'{lprefix}.tls', '')
+        else:
+            svc.remove_label(f'{lprefix}.tls')
